@@ -8,6 +8,8 @@ fnsload = """ ╔═══╗╔═╗ ╔╗╔═══╗╔╗     ╔╗
                             
                             
 """
+print(fnsload)
+
 def getgpt(tkn, req):
 	openai.api_key = tkn
 	resp = openai.Completion.create(
@@ -21,5 +23,5 @@ def getgpt(tkn, req):
 	return resp
 
 def getpass(symb):
-	return 'Generating pass, please wait...'
+	return print('Generating pass, please wait...')
 
